/* See LICENSE file for copyright and license details. */

#include "push.c"
#include "split.c"

/* appearance */
static const char font[]            = "-windows-dina-medium-r-normal--12-120-75-75-c-0-microsoft-cp1252";
static const char normbordercolor[] = "#333333";
static const char normbgcolor[]     = "#1a1a1a";
static const char normfgcolor[]     = "#cedbde";
static const char selbordercolor[]  = "#333333";
static const char selbgcolor[]      = "#333333";
static const char selfgcolor[]      = "#00e9ff";
static const char urgentcolor[]     = "#f1d910";
static const char emptycolor[]      = "#666666";
static const unsigned int borderpx  = 0;        /* border pixel of windows */
static const unsigned int gappx     = 1;        /* gap pixel between windows */
static const unsigned int snap      = 32;       /* snap pixel */
static const Bool showbar           = True;     /* False means no bar */
static const Bool topbar            = False;     /* False means bottom bar */

static const unsigned int floatborderpx = 1;        /* border pixel of windows */

/* tagging */
static const char *tags[] = { "1", "2", "3", "4", "5", "6", "7", "8", "9", "0" };

static const Rule rules[] = {
	/* xprop(1):
	 *	WM_CLASS(STRING) = instance, class
	 *	WM_NAME(STRING) = title
	 */
	/* class      instance    title       tags mask     isfloating   monitor */
	{ "Firefox",  NULL,       NULL,       1,            False,       0 },
	{ "Dwb",      NULL,       NULL,       1,            False,       0 },
	{ "Zathura",  NULL,       NULL,       -1,           False,       0 },
};

/* layout(s) */
static const float mfact      = 0.55; /* factor of master area size [0.05..0.95] */
static const int nmaster      = 1;    /* number of clients in master area */
static const Bool resizehints = False; /* True means respect size hints in tiled resizals */

static const Layout layouts[] = {
	/* symbol     arrange function */
	{ "+",        layout_vsplit },
	{ "=",        layout_hsplit },
};

/* key definitions */
#define MODKEY Mod4Mask
#define TAGKEYS(KEY,TAG) \
	{ MODKEY,                       KEY,      view,           {.ui = 1 << TAG} }, \
	{ MODKEY|ControlMask,           KEY,      toggleview,     {.ui = 1 << TAG} }, \
	{ MODKEY|ShiftMask,             KEY,      tag,            {.ui = 1 << TAG} }, \
	{ MODKEY|ControlMask|ShiftMask, KEY,      toggletag,      {.ui = 1 << TAG} },

/* helper for spawning shell commands in the pre dwm-5.0 fashion */
#define SHCMD(cmd) { .v = (const char*[]){ "/bin/sh", "-c", cmd, NULL } }

/* commands */
static char dmenumon[2] = "0"; /* component of dmenucmd, manipulated in spawn() */

static const char *dmenucmd[] = { "dmenu_run", "-b", NULL };
// static const char *cmd_term[]  = { "urxvt", NULL };
static const char *cmd_term[]  = { "st", "-e", "dvtm", NULL };
static const char *cmd_lock[]  = { "slock", NULL };
static const char *cmd_browser[]  = { "firefox", NULL };
static const char *cmd_play[]  = { "mpc", "toggle", "-q", NULL } ;
static const char *cmd_next[]  = { "mpc", "next", "-q", NULL };
static const char *cmd_mute[]  = { "amixer", "-q", "set", "Master", "toggle", NULL };
static const char *cmd_mpdmenu[]  = { "mpdmenu", NULL };
static const char *cmd_skype[]  = { "skype", NULL };
static const char *cmd_mutt[] = { "urxvt", "-e", "mutt", NULL };
static const char *cmd_pdb[] = { "pdbmenu", "-b", "-p", "pdb", NULL };
static const char *cmd_weechat[] = { "urxvt", "-e", "weechat", NULL };
static const char *cmd_todo[]  = { "todo", NULL };

static Key keys[] = {
	/* modifier                     key        function        argument */
	{ MODKEY,                       XK_p,      spawn,          { .v = dmenucmd } },
	{ MODKEY,                       XK_Return, spawn,          { .v = cmd_term } },
	{ MODKEY | ShiftMask,           XK_l,      spawn,          { .v = cmd_lock } },
	{ MODKEY,                       XK_f,      spawn,          { .v = cmd_browser } },
	{ MODKEY,                       XK_y,      spawn,          { .v = cmd_play } },
	{ MODKEY,                       XK_m,      spawn,          { .v = cmd_mute } },
	{ MODKEY,                       XK_t,      spawn,          { .v = cmd_mpdmenu } },
	{ MODKEY,                       XK_s,      spawn,          { .v = cmd_skype } },
	{ MODKEY,                       XK_e,      spawn,          { .v = cmd_mutt } },
	{ MODKEY,                       XK_w,      spawn,          { .v = cmd_pdb } },
	{ MODKEY,                       XK_i,      spawn,          { .v = cmd_weechat } },
	{ MODKEY,                       XK_d,      spawn,          { .v = cmd_todo } },

	{ MODKEY,                       XK_b,      togglebar,      {0} },
	{ MODKEY,                       XK_j,      focusstack,     {.i = +1 } },
	{ MODKEY,                       XK_k,      focusstack,     {.i = -1 } },
	{ MODKEY | ShiftMask,           XK_j,      pushdown,       { 0 } },
	{ MODKEY | ShiftMask,           XK_k,      pushup,         { 0 } },
	{ MODKEY,                       XK_x,      killclient,     {0} },
	{ MODKEY,                       XK_space,  setlayout,      {0} },
	{ MODKEY|ShiftMask,             XK_q,      quit,           { .i = 1 } },

	// { MODKEY,                       XK_i,      incnmaster,     {.i = +1 } },
	// { MODKEY,                       XK_d,      incnmaster,     {.i = -1 } },
	// { MODKEY,                       XK_h,      setmfact,       {.f = -0.05} },
	// { MODKEY,                       XK_l,      setmfact,       {.f = +0.05} },
	// { MODKEY,                       XK_Return, zoom,           {0} },
	// { MODKEY,                       XK_Tab,    view,           {0} },
	// { MODKEY,                       XK_t,      setlayout,      {.v = &layouts[0]} },
	// { MODKEY,                       XK_f,      setlayout,      {.v = &layouts[1]} },
	// { MODKEY,                       XK_m,      setlayout,      {.v = &layouts[2]} },
	// { MODKEY|ShiftMask,             XK_space,  togglefloating, {0} },
	// { MODKEY,                       XK_0,      view,           {.ui = ~0 } },
	// { MODKEY|ShiftMask,             XK_0,      tag,            {.ui = ~0 } },
	// { MODKEY,                       XK_comma,  focusmon,       {.i = -1 } },
	// { MODKEY,                       XK_period, focusmon,       {.i = +1 } },
	// { MODKEY|ShiftMask,             XK_comma,  tagmon,         {.i = -1 } },
	// { MODKEY|ShiftMask,             XK_period, tagmon,         {.i = +1 } },

	TAGKEYS(                        XK_1,                      0)
	TAGKEYS(                        XK_2,                      1)
	TAGKEYS(                        XK_3,                      2)
	TAGKEYS(                        XK_4,                      3)
	TAGKEYS(                        XK_5,                      4)
	TAGKEYS(                        XK_6,                      5)
	TAGKEYS(                        XK_7,                      6)
	TAGKEYS(                        XK_8,                      7)
	TAGKEYS(                        XK_9,                      8)
	TAGKEYS(                        XK_0,                      9)
};

/* button definitions */
/* click can be ClkLtSymbol, ClkStatusText, ClkWinTitle, ClkClientWin, or ClkRootWin */
static Button buttons[] = {
	/* click                event mask      button          function        argument */
	// { ClkLtSymbol,          0,              Button1,        setlayout,      {0} },
	// { ClkLtSymbol,          0,              Button3,        setlayout,      {.v = &layouts[2]} },
	// { ClkWinTitle,          0,              Button2,        zoom,           {0} },
	// { ClkStatusText,        0,              Button2,        spawn,          {.v = termcmd } },
	{ ClkClientWin,         MODKEY,         Button1,        movemouse,      {0} },
	{ ClkClientWin,         MODKEY,         Button2,        togglefloating, {0} },
	{ ClkClientWin,         MODKEY,         Button3,        resizemouse,    {0} },
	{ ClkTagBar,            0,              Button1,        view,           {0} },
	{ ClkTagBar,            0,              Button3,        toggleview,     {0} },
	{ ClkTagBar,            MODKEY,         Button1,        tag,            {0} },
	{ ClkTagBar,            MODKEY,         Button3,        toggletag,      {0} },

	{ ClkStatusText,        0,              Button1,        spawn,          { .v = cmd_play } },
	{ ClkStatusText,        0,              Button3,        spawn,          { .v = cmd_next } },
};

